==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Réinitialiser',
	'boxstr_close' => 'Fermer',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Suivant',
	'boxstr_previous' => 'Précédent',
	'boxstr_slideshowStart' => 'Diaporama',
	'boxstr_slideshowStop' => 'Arrêter',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indiquez la cible des éléments qui déclencheront la boîte. (Expression CSS ou étendue jQuery)',
	'explication_selecteur_galerie' => 'Indiquez la cible des éléments à regrouper en galerie. (Expression CSS ou étendue jQuery)',
	'explication_splash_url' => 'Indiquez l’url du média à afficher automatiquement dans une boîte lors de la première visite sur le site public.',
	'explication_traiter_toutes_images' => 'Insérer une boîte sur toutes les images ?',

	// L
	'label_active' => 'Activer la Boîte Multimédia dans le site public',
	'label_apparence' => 'Apparence',
	'label_aucun_style' => 'N’insérer aucun habillage par défaut',
	'label_choix_transition_elastic' => 'Élastique',
	'label_choix_transition_fade' => 'Fondu enchaîné',
	'label_choix_transition_none' => 'Sans effet de transition',
	'label_maxheight' => 'Hauteur Maxi (% ou px)',
	'label_maxwidth' => 'Largeur Maxi (% ou px)',
	'label_minheight' => 'Hauteur Mini (% ou px)',
	'label_minwidth' => 'Largeur Mini (% ou px)',
	'label_opacite' => 'Opacité du fond',
	'label_selecteur_commun' => 'En général',
	'label_selecteur_galerie' => 'En galerie',
	'label_skin' => 'Habillage visuel',
	'label_slideshow_speed' => 'Temps d’exposition des photos du diaporama (ms)',
	'label_speed' => 'Vitesse de transition (ms)',
	'label_splash' => 'Splash Boîte',
	'label_splash_url' => 'URL à afficher',
	'label_traiter_toutes_images' => 'Images',
	'label_transition' => 'Transition entre deux affichages',

	// T
	'titre_menu_box' => 'Boîte Multimédia',
	'titre_page_configurer_box' => 'Configuration de la Boîte multimédia'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/mediabox/lang/mediabox_fr_fem.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/mediabox?lang_cible=fr_fem
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_reinitialiser' => 'Réinitialiser',
	'boxstr_close' => 'Fermer',
	'boxstr_current' => '@current@/@total@',
	'boxstr_next' => 'Suivant',
	'boxstr_previous' => 'Précédent',
	'boxstr_slideshowStart' => 'Diaporama',
	'boxstr_slideshowStop' => 'Arrêter',
	'boxstr_zoom' => 'Zoom',

	// E
	'explication_selecteur' => 'Indiquez la cible des éléments qui déclencheront la boîte. (Expression CSS ou étendue jQuery)',
	'explication_selecteur_galerie' => 'Indiquez la cible des éléments à regrouper en galerie. (Expression CSS ou étendue jQuery)',
	'explication_splash_url' => 'Indiquez l’url du média à afficher automatiquement dans une boîte lors de la première visite sur le site public.',
	'explication_traiter_toutes_images' => 'Insérer une boîte sur toutes les images ?',

	// L
	'label_active' => 'Activer la Boîte Multimédia dans le site public',
	'label_apparence' => 'Apparence',
	'label_aucun_style' => 'N’insérer aucun habillage par défaut',
	'label_choix_transition_elastic' => 'Élastique',
	'label_choix_transition_fade' => 'Fondu enchaîné',
	'label_choix_transition_none' => 'Sans effet de transition',
	'label_maxheight' => 'Hauteur Maxi (% ou px)',
	'label_maxwidth' => 'Largeur Maxi (% ou px)',
	'label_minheight' => 'Hauteur Mini (% ou px)',
	'label_minwidth' => 'Largeur Mini (% ou px)',
	'label_opacite' => 'Opacité du fond',
	'label_selecteur_commun' => 'En général',
	'label_selecteur_galerie' => 'En galerie',
	'label_skin' => 'Habillage visuel',
	'label_slideshow_speed' => 'Temps d’exposition des photos du diaporama (ms)',
	'label_speed' => 'Vitesse de transition (ms)',
	'label_splash' => 'Splash Boîte',
	'label_splash_height' => 'Hauteur (% ou px)',
	'label_splash_url' => 'URL à afficher',
	'label_splash_width' => 'Largeur (% ou px)',
	'label_traiter_toutes_images' => 'Images',
	'label_transition' => 'Transition entre deux affichages',

	// T
	'titre_menu_box' => 'Boîte Multimédia',
	'titre_page_configurer_box' => 'Configuration de la Boîte multimédia'
);

?>
